@@ -134,7 +134,7 @@ for dir in dirlist:
 
     sourcepublic = False
     id = dir
-    if (type == 'group'):
+    if (type != 'tool'):
       gid = []
       gid.append(id)
       gid.append('apps')
